# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.4.1
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.schedules_.post import SchedulesCreate
from galv.paths.schedules_describe_.get import SchedulesDescribeRetrieve
from galv.paths.schedules_id_.delete import SchedulesDestroy
from galv.paths.schedules_.get import SchedulesList
from galv.paths.schedules_id_.patch import SchedulesPartialUpdate
from galv.paths.schedules_id_.get import SchedulesRetrieve


class SchedulesApi(
    SchedulesCreate,
    SchedulesDescribeRetrieve,
    SchedulesDestroy,
    SchedulesList,
    SchedulesPartialUpdate,
    SchedulesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
