# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.4.1
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.labs_.post import LabsCreate
from galv.paths.labs_describe_.get import LabsDescribeRetrieve
from galv.paths.labs_id_.delete import LabsDestroy
from galv.paths.labs_.get import LabsList
from galv.paths.labs_id_.patch import LabsPartialUpdate
from galv.paths.labs_id_.get import LabsRetrieve


class LabsApi(
    LabsCreate,
    LabsDescribeRetrieve,
    LabsDestroy,
    LabsList,
    LabsPartialUpdate,
    LabsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
