# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.4.1
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.cells_.post import CellsCreate
from galv.paths.cells_describe_.get import CellsDescribeRetrieve
from galv.paths.cells_id_.delete import CellsDestroy
from galv.paths.cells_.get import CellsList
from galv.paths.cells_id_.patch import CellsPartialUpdate
from galv.paths.cells_id_rdf_.get import CellsRdfRetrieve
from galv.paths.cells_id_.get import CellsRetrieve


class CellsApi(
    CellsCreate,
    CellsDescribeRetrieve,
    CellsDestroy,
    CellsList,
    CellsPartialUpdate,
    CellsRdfRetrieve,
    CellsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
