# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.4.1
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.additional_storage_.post import AdditionalStorageCreate
from galv.paths.additional_storage_describe_.get import AdditionalStorageDescribeRetrieve
from galv.paths.additional_storage_id_.delete import AdditionalStorageDestroy
from galv.paths.additional_storage_.get import AdditionalStorageList
from galv.paths.additional_storage_id_.patch import AdditionalStoragePartialUpdate
from galv.paths.additional_storage_id_.get import AdditionalStorageRetrieve


class AdditionalStorageApi(
    AdditionalStorageCreate,
    AdditionalStorageDescribeRetrieve,
    AdditionalStorageDestroy,
    AdditionalStorageList,
    AdditionalStoragePartialUpdate,
    AdditionalStorageRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
